Extent

Struct Extent 

pub struct Extent<S: Scalar> {
    pub center: Vector3<S>,
    pub size: S,
}
Where the drawing is and how big: the center and diagonal (at least 1) of the box around it. Datum planes and axes, which are endless, are drawn this big around the point of them nearest the center.

Fields

center: Vector3<S>size: S